load_worldcoin_data

Function load_worldcoin_data 

pub fn load_worldcoin_data<F: Field>(
    image_bytes: Vec<u8>,
    is_mask: bool,
) -> IriscodeCircuitInputData<F>
Loads circuit structure data and witnesses for a run of the iris code circuit from disk for either the iris or mask case.

Arguments:

  • image_bytes gives the bytes of an image (could be the iris or the mask).
  • is_mask indicates whether to load the files for the mask or the iris.