pub fn load_worldcoin_data<F: Field>(
image_bytes: Vec<u8>,
is_mask: bool,
) -> IriscodeCircuitInputData<F>Expand description
Loads circuit structure data and witnesses for a run of the iris code circuit from disk for either the iris or mask case.
Arguments:
image_bytesgives the bytes of an image (could be the iris or the mask).is_maskindicates whether to load the files for the mask or the iris.